Crate credibil_dwn

Crate credibil_dwn 

Decentralized Web Node (DWN)

A Decentralized Web Node (DWN) is a data storage and message relay mechanism entities can use to locate public or private permissioned data related to a given Decentralized Identifier (DID). Decentralized Web Nodes are designed to be deployed in mesh-like datastore construct that enables an entity to operate multiple nodes that replicate state across all nodes.

A DWN allows the owning entity to secure, manage, and transact data with others without reliance on location or provider-specific infrastructure, interfaces, or routing mechanisms.

Re-exports

pub use crate::endpoint::Message;
pub use crate::provider::Provider;

Modules

authorization
Authorization
cid
Content Identifier (CID) utilities.
client
Client
endpoint
Endpoint
event
Event
hd_key
Hierarchical Deterministic Key
interfaces
Interfaces
provider
Provider
store
Store

Macros

bad
Construct an Error::BadRequest error from a string or existing error value.
forbidden
Construct an Error::Forbidden error from a string or existing error value.
unauthorized
Construct an Error::Unauthorized error from a string or existing error value.

Structs

StatusCode
An HTTP status code (status-code in RFC 9110 et al.).

Enums

Error
The Error type represents all errors that may be returned by a DWN.
Interface
Web node interfaces.
Method
Interface methods.
OneOrMany
OneOrMany allows serde to serialize/deserialize a single object or a set of objects.
Protocol
Interface protocols.

Traits

BlockStore
BlockStore is used by implementers to provide data storage capability.
Receiver
A Receiver (Recipient) is required to decrypt an encrypted message.
Signer
Signer is used by implementers to provide signing functionality for Verifiable Credential issuance and Verifiable Presentation submissions.

Type Aliases

Result
Result type for DWN handlers.