pub struct PathEncryption {
pub root_key_id: String,
pub public_key_jwk: PublicKeyJwk,
}Expand description
Config for protocol-path encryption scheme.
Fields
root_key_id: StringThe ID of the root key that derives the public key at this protocol path for encrypting the symmetric key used for data encryption.
public_key_jwk: PublicKeyJwkPublic key for encrypting the symmetric key used for data encryption.