Decentralized Web Node (DWN)
A Decentralized Web Node (DWN) is a data storage and message relay mechanism entities can use to locate public or private permissioned data related to a given Decentralized Identifier (DID). Decentralized Web Nodes are designed to be deployed in mesh-like datastore construct that enables an entity to operate multiple nodes that replicate state across all nodes.
A DWN allows the owning entity to secure, manage, and transact data with others without reliance on location or provider-specific infrastructure, interfaces, or routing mechanisms.
Re-exports
Modules
- authorization
- Authorization
- cid
- Content Identifier (CID) utilities.
- client
- Client
- endpoint
- Endpoint
- event
- Event
- hd_key
- Hierarchical Deterministic Key
- interfaces
- Interfaces
- provider
- Provider
- store
- Store
Macros
- bad
- Construct an
Error::BadRequesterror from a string or existing error value. - forbidden
- Construct an
Error::Forbiddenerror from a string or existing error value. - unauthorized
- Construct an
Error::Unauthorizederror from a string or existing error value.
Structs
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.).
Enums
- Error
- The Error type represents all errors that may be returned by a
DWN. - Interface
- Web node interfaces.
- Method
- Interface methods.
- OneOr
Many OneOrManyallows serde to serialize/deserialize a single object or a set of objects.- Protocol
- Interface protocols.
Traits
- Block
Store BlockStoreis used by implementers to provide data storage capability.- Receiver
- A Receiver (Recipient) is required to decrypt an encrypted message.
- Signer
- Signer is used by implementers to provide signing functionality for Verifiable Credential issuance and Verifiable Presentation submissions.
Type Aliases
- Result
- Result type for
DWNhandlers.